.. This is your project NEWS file which will contain the release notes.
.. Example: http://www.python.org/download/releases/2.6/NEWS.txt
.. The content of this file, along with README.rst, will appear in your
.. project's PyPI page.

News
====

0.2
---
*Release date: 28-Jan-2025*

* Add support for Python versions 3.8 to 3.13.
* Drop support for Python 2.
* Add tox testing support.
* Add pre-commit and linting.
* Add NEWS.rst releases file.


0.1
---

*Release date: 08-Aug-2022*

* Initial release of difftacular.
